@@ -156,8 +156,6 @@ class JinjaStaticRenderer():
         new_file_path = page.get_output_path()
         new_directory = os.path.split(new_file_path)[0]
         
-        print "Last built at: %s, page mtime: %s" % (last_build_time, page.get_modified_time())
-
         # Force a render if the output file doesn't exist
         if not os.path.exists(new_file_path) or page.get_modified_time() >= last_build_time:
             force_render = 1
@@ -182,10 +180,16 @@ class JinjaStaticRenderer():
         if template_modified_time >= last_build_time:
             force_render = 1
 
+        ref_template_mtime = 0
         for t in referenced_templates:
             time = self.get_template_mtime(t)
             if time >= last_build_time:
                 force_render = 1
+                ref_template_mtime = time
+
+
+        print "Last built at: %s, page mtime: %s, templ mtime: %s, ref-templates mtime: %s" % (last_build_time, page.get_modified_time(), template_modified_time, ref_template_mtime)
+
 
         file_did_render = 0
 
